@@ -79,26 +79,32 @@ class UTC(datetime.tzinfo):
         """No daylight saving for UTC."""
         return datetime.timedelta(hours=1)
 
-class _FixedOffset(datetime.tzinfo):
-    """Fixed offset in minutes east from UTC.
-    Copy/pasted from Python doc
-    :param int offset: offset in minutes
-    """
+try:
+    from datetime import timezone as _FixedOffset
+except ImportError:  # Python 2.7
+    class _FixedOffset(datetime.tzinfo):  # type: ignore
+        """Fixed offset in minutes east from UTC.
+        Copy/pasted from Python doc
+        :param datetime.timedelta offset: offset in timedelta format
+        """
 
-    def __init__(self, offset):
-        self.__offset = datetime.timedelta(minutes=offset)
+        def __init__(self, offset):
+            self.__offset = offset
 
-    def utcoffset(self, dt):
-        return self.__offset
+        def utcoffset(self, dt):
+            return self.__offset
 
-    def tzname(self, dt):
-        return str(self.__offset.total_seconds()/3600)
+        def tzname(self, dt):
+            return str(self.__offset.total_seconds()/3600)
 
-    def __repr__(self):
-        return "<FixedOffset {}>".format(self.tzname(None))
+        def __repr__(self):
+            return "<FixedOffset {}>".format(self.tzname(None))
 
-    def dst(self, dt):
-        return datetime.timedelta(0)
+        def dst(self, dt):
+            return datetime.timedelta(0)
+
+        def __getinitargs__(self):
+            return (self.__offset,)
 
 try:
     from datetime import timezone
@@ -513,7 +519,12 @@ class Serializer(object):
                     if is_xml_model_serialization:
                         xml_desc = attr_desc.get('xml', {})
                         xml_name = xml_desc.get('name', attr_desc['key'])
+                        xml_prefix = xml_desc.get('prefix', None)
+                        xml_ns = xml_desc.get('ns', None)
                         if xml_desc.get("attr", False):
+                            if xml_ns:
+                                ET.register_namespace(xml_prefix, xml_ns)
+                                xml_name = "{{{}}}{}".format(xml_ns, xml_name)
                             serialized.set(xml_name, new_attr)
                             continue
                         if isinstance(new_attr, list):
@@ -531,8 +542,8 @@ class Serializer(object):
                             # Integrate namespace if necessary
                             local_node = _create_xml_node(
                                 xml_name,
-                                xml_desc.get('prefix', None),
-                                xml_desc.get('ns', None)
+                                xml_prefix,
+                                xml_ns
                             )
                             local_node.text = unicode_str(new_attr)
                             serialized.append(local_node)
@@ -1188,6 +1199,21 @@ def attribute_key_case_insensitive_extractor(attr, _, data):
 
     return data.get(found_key)
 
+def _extract_name_from_internal_type(internal_type):
+    """Given an internal type XML description, extract correct XML name with namespace.
+
+    :param dict internal_type: An model type
+    :rtype: tuple
+    :returns: A tuple XML name + namespace dict
+    """
+    internal_type_xml_map = getattr(internal_type, "_xml_map", {})
+    xml_name = internal_type_xml_map.get('name', internal_type.__name__)
+    xml_ns = internal_type_xml_map.get("ns", None)
+    if xml_ns:
+        xml_name = "{{{}}}{}".format(xml_ns, xml_name)
+    return xml_name
+
+
 def xml_key_extractor(attr, attr_desc, data):
     if isinstance(data, dict):
         return None
@@ -1198,44 +1224,39 @@ def xml_key_extractor(attr, attr_desc, data):
 
     xml_desc = attr_desc.get('xml', {})
     xml_name = xml_desc.get('name', attr_desc['key'])
-    xml_ns = xml_desc.get('ns', None)
-
-    # If it's an attribute, that's simple
-    if xml_desc.get("attr", False):
-        return data.get(xml_name)
-
-    # Integrate namespace if necessary
-    if xml_ns:
-        ns = {'prefix': xml_ns}
-        xml_name = "prefix:"+xml_name
-    else:
-        ns = {} # And keep same xml_name
 
     # Look for a children
     is_iter_type = attr_desc['type'].startswith("[")
     is_wrapped = xml_desc.get("wrapped", False)
     internal_type = attr_desc.get("internalType", None)
+    internal_type_xml_map = getattr(internal_type, "_xml_map", {})
+
+    # Integrate namespace if necessary
+    xml_ns = xml_desc.get('ns', internal_type_xml_map.get("ns", None))
+    if xml_ns:
+        xml_name = "{{{}}}{}".format(xml_ns, xml_name)
+
+    # If it's an attribute, that's simple
+    if xml_desc.get("attr", False):
+        return data.get(xml_name)
 
     # Scenario where I take the local name:
     # - Wrapped node
     # - Internal type is an enum (considered basic types)
     # - Internal type has no XML/Name node
-    internal_type_xml_map = getattr(internal_type, "_xml_map", {})
     if is_wrapped or (internal_type and (issubclass(internal_type, Enum) or 'name' not in internal_type_xml_map)):
-        children = data.findall(xml_name, ns)
+        children = data.findall(xml_name)
     # If internal type has a local name and it's not a list, I use that name
     elif not is_iter_type and internal_type and 'name' in internal_type_xml_map:
-        xml_name = internal_type_xml_map["name"]
-        ns = internal_type_xml_map.get("ns", None)
-        children = data.findall(xml_name, ns)
+        xml_name = _extract_name_from_internal_type(internal_type)
+        children = data.findall(xml_name)
     # That's an array
     else:
         if internal_type: # Complex type, ignore itemsName and use the complex type name
-            items_name = internal_type_xml_map.get('name', internal_type.__name__)
-            ns = internal_type_xml_map.get("ns", None)
+            items_name = _extract_name_from_internal_type(internal_type)
         else:
             items_name = xml_desc.get("itemsName", xml_name)
-        children = data.findall(items_name, ns)
+        children = data.findall(items_name)
 
     if len(children) == 0:
         if is_iter_type:
@@ -1852,7 +1873,7 @@ class Deserializer(object):
             parsed_date = email.utils.parsedate_tz(attr)
             date_obj = datetime.datetime(
                 *parsed_date[:6],
-                tzinfo=_FixedOffset((parsed_date[9] or 0)/60)
+                tzinfo=_FixedOffset(datetime.timedelta(minutes=(parsed_date[9] or 0)/60))
             )
             if not date_obj.tzinfo:
                 date_obj = date_obj.astimezone(tz=TZ_UTC)
